]> asedeno.scripts.mit.edu Git - PuTTY.git/blobdiff - putty.h
We may as well update the website icon to match the other new ones.
[PuTTY.git] / putty.h
diff --git a/putty.h b/putty.h
index a821b243200567ffd29b49a30eac443c5e070b6e..b003652c36e75e4baed0c1c95c20e1a09168dbd8 100644 (file)
--- a/putty.h
+++ b/putty.h
@@ -297,6 +297,11 @@ enum {
     LD_ECHO                           /* local echo */
 };
 
+enum {
+    /* Actions on remote window title query */
+    TITLE_NONE, TITLE_EMPTY, TITLE_REAL
+};
+
 enum {
     /* Protocol back ends. (cfg.protocol) */
     PROT_RAW, PROT_TELNET, PROT_RLOGIN, PROT_SSH,
@@ -486,7 +491,7 @@ struct config_tag {
     int no_remote_wintitle;           /* disable remote retitling */
     int no_dbackspace;                /* disable destructive backspace */
     int no_remote_charset;            /* disable remote charset config */
-    int no_remote_qtitle;             /* disable remote win title query */
+    int remote_qtitle_action;         /* remote win title query action */
     int app_cursor;
     int app_keypad;
     int nethack_keypad;
@@ -1087,6 +1092,7 @@ typedef struct bidi_char {
 } bidi_char;
 int do_bidi(bidi_char *line, int count);
 int do_shape(bidi_char *line, bidi_char *to, int count);
+int is_rtl(int c);
 
 /*
  * X11 auth mechanisms we know about.